@@ -31,16 +31,20 @@ class AddDeviceRequest(AbstractModel):
         :type Remark: str
         :param DataKey: 新建设备的base64密钥字符串，非必选，如果不填写则由系统自动生成
         :type DataKey: str
+        :param Encrypted: 是否设置预置密钥
+        :type Encrypted: bool
         """
         self.DeviceName = None
         self.Remark = None
         self.DataKey = None
+        self.Encrypted = None
 
 
     def _deserialize(self, params):
         self.DeviceName = params.get("DeviceName")
         self.Remark = params.get("Remark")
         self.DataKey = params.get("DataKey")
+        self.Encrypted = params.get("Encrypted")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -57,21 +61,26 @@ class AddDeviceResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param DataKey: 后台生成的base64字符串密钥
+        :param DataKey: 经过加密算法加密后的base64格式密钥
         :type DataKey: str
         :param DeviceId: 设备ID
         :type DeviceId: str
+        :param Signature: 签名字符串
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Signature: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.DataKey = None
         self.DeviceId = None
+        self.Signature = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
         self.DataKey = params.get("DataKey")
         self.DeviceId = params.get("DeviceId")
+        self.Signature = params.get("Signature")
         self.RequestId = params.get("RequestId")
 
 
@@ -141,6 +150,33 @@ class Context(AbstractModel):
         
 
 
+class CreateEncryptedKeyRequest(AbstractModel):
+    """CreateEncryptedKey请求参数结构体
+
+    """
+
+
+class CreateEncryptedKeyResponse(AbstractModel):
+    """CreateEncryptedKey返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param EncryptedKey: 预置密钥
+        :type EncryptedKey: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.EncryptedKey = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.EncryptedKey = params.get("EncryptedKey")
+        self.RequestId = params.get("RequestId")
+
+
 class CreateQosRequest(AbstractModel):
     """CreateQos请求参数结构体
 
@@ -480,9 +516,21 @@ class DeviceDetails(AbstractModel):
         :param DeviceNetInfo: 设备网络信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type DeviceNetInfo: list of DeviceNetInfo
+        :param GatewaySite: 聚合服务器地址
+注意：此字段可能返回 null，表示取不到有效值。
+        :type GatewaySite: str
+        :param BusinessDownRate: 业务下行速率
+注意：此字段可能返回 null，表示取不到有效值。
+        :type BusinessDownRate: float
+        :param BusinessUpRate: 业务上行速率
+注意：此字段可能返回 null，表示取不到有效值。
+        :type BusinessUpRate: float
         """
         self.DeviceBaseInfo = None
         self.DeviceNetInfo = None
+        self.GatewaySite = None
+        self.BusinessDownRate = None
+        self.BusinessUpRate = None
 
 
     def _deserialize(self, params):
@@ -495,6 +543,9 @@ class DeviceDetails(AbstractModel):
                 obj = DeviceNetInfo()
                 obj._deserialize(item)
                 self.DeviceNetInfo.append(obj)
+        self.GatewaySite = params.get("GatewaySite")
+        self.BusinessDownRate = params.get("BusinessDownRate")
+        self.BusinessUpRate = params.get("BusinessUpRate")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -615,6 +666,12 @@ class DeviceNetInfo(AbstractModel):
         :param NetInfoName: 网卡名
 注意：此字段可能返回 null，表示取不到有效值。
         :type NetInfoName: str
+        :param DownRate: 下行实时速率（浮点数类型代替上一版本DataRx的整型）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DownRate: float
+        :param UpRate: 上行实时速率（浮点数类型代替上一版本TxRate的整型）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type UpRate: float
         """
         self.Type = None
         self.DataEnable = None
@@ -628,6 +685,8 @@ class DeviceNetInfo(AbstractModel):
         self.SignalStrength = None
         self.Rat = None
         self.NetInfoName = None
+        self.DownRate = None
+        self.UpRate = None
 
 
     def _deserialize(self, params):
@@ -643,6 +702,8 @@ class DeviceNetInfo(AbstractModel):
         self.SignalStrength = params.get("SignalStrength")
         self.Rat = params.get("Rat")
         self.NetInfoName = params.get("NetInfoName")
+        self.DownRate = params.get("DownRate")
+        self.UpRate = params.get("UpRate")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -684,6 +745,56 @@ class ExpectedThreshold(AbstractModel):
         
 
 
+class FlowDetails(AbstractModel):
+    """设备流量信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param NetDetails: 流量数据点
+注意：此字段可能返回 null，表示取不到有效值。
+        :type NetDetails: list of NetDetails
+        :param DeviceId: 设备ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DeviceId: str
+        :param MaxValue: 流量最大值（单位：bytes）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type MaxValue: float
+        :param AvgValue: 流量平均值（单位：bytes）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AvgValue: float
+        :param TotalValue: 流量总值（单位：bytes）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TotalValue: float
+        """
+        self.NetDetails = None
+        self.DeviceId = None
+        self.MaxValue = None
+        self.AvgValue = None
+        self.TotalValue = None
+
+
+    def _deserialize(self, params):
+        if params.get("NetDetails") is not None:
+            self.NetDetails = []
+            for item in params.get("NetDetails"):
+                obj = NetDetails()
+                obj._deserialize(item)
+                self.NetDetails.append(obj)
+        self.DeviceId = params.get("DeviceId")
+        self.MaxValue = params.get("MaxValue")
+        self.AvgValue = params.get("AvgValue")
+        self.TotalValue = params.get("TotalValue")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class GetDeviceRequest(AbstractModel):
     """GetDevice请求参数结构体
 
@@ -804,7 +915,7 @@ class GetFlowStatisticRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param DeviceId: 设备ID，ID="-1"时默认查找所有设备
+        :param DeviceId: 设备ID
         :type DeviceId: str
         :param BeginTime: 开始查找时间
         :type BeginTime: int
@@ -875,6 +986,99 @@ class GetFlowStatisticResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class GetMultiFlowStatisticRequest(AbstractModel):
+    """GetMultiFlowStatistic请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param DeviceIds: 设备id列表，单次最多请求10个设备
+        :type DeviceIds: list of str
+        :param BeginTime: 1659514436
+        :type BeginTime: int
+        :param EndTime: 1659515000
+        :type EndTime: int
+        :param Type: 统计流量类型（1：上行流量，2：下行流量）
+        :type Type: int
+        :param TimeGranularity: 统计时间粒度（1：按小时统计，2：按天统计）
+        :type TimeGranularity: int
+        """
+        self.DeviceIds = None
+        self.BeginTime = None
+        self.EndTime = None
+        self.Type = None
+        self.TimeGranularity = None
+
+
+    def _deserialize(self, params):
+        self.DeviceIds = params.get("DeviceIds")
+        self.BeginTime = params.get("BeginTime")
+        self.EndTime = params.get("EndTime")
+        self.Type = params.get("Type")
+        self.TimeGranularity = params.get("TimeGranularity")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class GetMultiFlowStatisticResponse(AbstractModel):
+    """GetMultiFlowStatistic返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param FlowDetails: 批量设备流量信息
+        :type FlowDetails: list of FlowDetails
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.FlowDetails = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("FlowDetails") is not None:
+            self.FlowDetails = []
+            for item in params.get("FlowDetails"):
+                obj = FlowDetails()
+                obj._deserialize(item)
+                self.FlowDetails.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
+class GetPublicKeyRequest(AbstractModel):
+    """GetPublicKey请求参数结构体
+
+    """
+
+
+class GetPublicKeyResponse(AbstractModel):
+    """GetPublicKey返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PublicKey: 非对称公钥
+        :type PublicKey: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.PublicKey = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.PublicKey = params.get("PublicKey")
+        self.RequestId = params.get("RequestId")
+
+
 class GetStatisticDataRequest(AbstractModel):
     """GetStatisticData请求参数结构体
 
@@ -882,7 +1086,7 @@ class GetStatisticDataRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param DeviceId: 设备ID，设备ID="-1"获取所有设备流量统计
+        :param DeviceId: 设备ID
         :type DeviceId: str
         :param BeginTime: 统计开始时间，单位：s
         :type BeginTime: int
@@ -941,18 +1145,18 @@ class NetDetails(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Time: 时间点，单位：s
-        :type Time: str
         :param Current: 流量值（bit）
         :type Current: float
+        :param Time: 时间点，单位：s
+        :type Time: str
         """
-        self.Time = None
         self.Current = None
+        self.Time = None
 
 
     def _deserialize(self, params):
-        self.Time = params.get("Time")
         self.Current = params.get("Current")
+        self.Time = params.get("Time")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
