@@ -35,6 +35,9 @@ FAILEDOPERATION_AUTHFAILURE = 'FailedOperation.AuthFailure'
 # 请求role信息失败。
 FAILEDOPERATION_CALLROLEFAILED = 'FailedOperation.CallRoleFailed'
 
+# CLS服务未注册。
+FAILEDOPERATION_CLSSERVICEUNREGISTERED = 'FailedOperation.ClsServiceUnregistered'
+
 # CopyAsyncRun 传参异常。
 FAILEDOPERATION_COPYASYNCRUN = 'FailedOperation.CopyAsyncRun'
 
@@ -188,12 +191,18 @@ INTERNALERROR_EXCEPTION = 'InternalError.Exception'
 # 内部服务错误。
 INTERNALERROR_GETROLEERROR = 'InternalError.GetRoleError'
 
+# 获取sts票据信息失败。
+INTERNALERROR_GETSTSTOKENFAILED = 'InternalError.GetStsTokenFailed'
+
 # 内部系统错误。
 INTERNALERROR_SYSTEM = 'InternalError.System'
 
 # 内部服务错误。
 INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 
+# 日志参数有误。
+INVALIDPARAMETER_CLS = 'InvalidParameter.Cls'
+
 # FunctionName取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
 INVALIDPARAMETER_FUNCTIONNAME = 'InvalidParameter.FunctionName'
 
@@ -299,6 +308,9 @@ INVALIDPARAMETERVALUE_COSBUCKETNAME = 'InvalidParameterValue.CosBucketName'
 # CosBucketRegion取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
 INVALIDPARAMETERVALUE_COSBUCKETREGION = 'InvalidParameterValue.CosBucketRegion'
 
+# COS通知规则冲突。
+INVALIDPARAMETERVALUE_COSNOTIFYRULECONFLICT = 'InvalidParameterValue.CosNotifyRuleConflict'
+
 # CosObjectName不符合规范。
 INVALIDPARAMETERVALUE_COSOBJECTNAME = 'InvalidParameterValue.CosObjectName'
 
@@ -644,6 +656,9 @@ MISSINGPARAMETER_CODE = 'MissingParameter.Code'
 # 缺失 Runtime 字段。
 MISSINGPARAMETER_RUNTIME = 'MissingParameter.Runtime'
 
+# 账号已被隔离。
+OPERATIONDENIED_ACCOUNTISOLATE = 'OperationDenied.AccountIsolate'
+
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
@@ -824,6 +839,9 @@ UNSUPPORTEDOPERATION_COS = 'UnsupportedOperation.Cos'
 # 指定的配置EipFixed暂不支持。
 UNSUPPORTEDOPERATION_EIPFIXED = 'UnsupportedOperation.EipFixed'
 
+# 不支持的地域。
+UNSUPPORTEDOPERATION_NOTSUPPORTREGION = 'UnsupportedOperation.NotSupportRegion'
+
 # 不支持此地域。
 UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 
